@@ -118,7 +118,7 @@ class Get_ASM_Consume:
             try:
                 df = pd.read_csv('%s' % (self.yes_file_path), header=None)
             except:
-                abnormal_push = DingDing_Push('ASM异常推送告知', '**当前读取前一日存储账单记录异常，已再向前读取1日，数据或出现偏移，请注意确认！**', push_url=self.push_token)
+                abnormal_push = DingDing_Push('ASM异常推送告知', '**推送标题：异常告警提示**\n**提示内容：**当前读取前一日存储账单记录异常，已向前读取1日，数据或出现偏移，请注意确认！**', push_url=self.push_token)
                 abnormal_push.app_args_push()
                 df = pd.read_csv('%s' % (self.yes_yes_file_path), header=None)
 
